<?php

namespace App\Admin\Controllers\Market;

use App\Models\RechargeCombo;
use App\Models\UserRechargeRecord;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Show;
use Dcat\Admin\Http\Controllers\AdminController;

class UserRechargeRecordController extends AdminController
{
    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        return Grid::make(UserRechargeRecord::with(['user','combo','pay']), function (Grid $grid) {
            $grid->model()->where('status',1)
                ->orderByDesc('id');
            $grid->column('id')->sortable();
            $grid->column('user.nickname','昵称');
            $grid->column('combo.name','充值套餐');
            $grid->column('price');
            $grid->column('gift');
            $grid->column('created_at','充值时间');

            $grid->filter(function (Grid\Filter $filter) {
                $filter->panel();
                $filter->like('user.nickname','昵称')->width(3);
                $filter->equal('combo.id','充值套餐')->select(function (){
                    return RechargeCombo::select(['id','name'])->get()->pluck('name','id')->toArray();
                })->width(3);
                $filter->between('created_at','充值时间')->datetime()->width(3);

            });

            $grid->disableDeleteButton();
            $grid->disableCreateButton();
            $grid->disableViewButton();
            $grid->disableRowSelector();
        });
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     *
     * @return Show
     */
    protected function detail($id)
    {
        return Show::make($id, new UserRechargeRecord(), function (Show $show) {
            $show->field('id');
            $show->field('user_id');
            $show->field('combo_id');
            $show->field('price');
            $show->field('gift');
            $show->field('pay_id');
            $show->field('created_at');
            $show->field('updated_at');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new UserRechargeRecord(), function (Form $form) {
            $form->display('id');
            $form->text('user_id');
            $form->text('combo_id');
            $form->text('price');
            $form->text('gift');
            $form->text('pay_id');

            $form->display('created_at');
            $form->display('updated_at');
        });
    }
}
